# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 1.3.x   | :white_check_mark: |
| 1.2.x   | :white_check_mark: |
| 1.1.x   | :x:                |
| 1.0.x   | :x:                |
| 0.x.x   | :x:                |

## Reporting a Vulnerability

Should you find a vulnerability in this package do not hesitate to get in touch with package owner, email address in [README.md](README.md)
